@@ -32,10 +32,8 @@ if TYPE_CHECKING:
 @contextmanager
 def youtube_session() -> Iterator[requests.Session]:
     """This context opens a requests session and loads the youtube cookies file."""
-    session = requests.session()
 
     pickle_file = os.path.join(settings.BASE_DIR, "config/youtube_cookies.pickle")
-
     session = requests.session()
     # Have youtube-dl deal with consent cookies etc to setup a valid session
     extractor = youtube_dl.extractor.youtube.YoutubeIE()
@@ -291,7 +289,7 @@ class YoutubeSongProvider(SongProvider, Youtube):
         # discard everything after the first v= parameter
         return "https://www.youtube.com" + cast(str, url).split("&")[0]
 
-    def request_radio(self, request_ip: str) -> HttpResponse:
+    def request_radio(self, session_key: str) -> HttpResponse:
         if not self.id:
             raise ValueError()
         radio_id = "RD" + self.id
