@@ -1,7 +1,5 @@
-"""
-ASGI entrypoint. Configures Django and then runs the application
-defined in the ASGI_APPLICATION setting.
-"""
+"""ASGI entrypoint. Configures Django and then runs the application
+defined in the ASGI_APPLICATION setting."""
 
 import os
 import django
